﻿namespace U2UConsult.WCF.Configuration.Sample
{
    using System;
    using ServiceReference;

    /// <summary>
    /// Proxy to the DummyService that takes its configuration from a custom file.
    /// </summary>
    public class CustomServiceClient : DummyServiceClient
    {
        /// <summary>
        /// Path to the custom configuration file.
        /// </summary>
        private string configurationFilePath;

        /// <summary>
        /// Initializes a new instance of the CustomServiceClient class.
        /// </summary>
        /// <param name="configurationFilePath">Path to the custom configuration file.</param>
        public CustomServiceClient(string configurationFilePath)
            : base()
        {
            this.configurationFilePath = configurationFilePath;
        }

        /// <summary>
        /// Creates a channel that implements the service interface.
        /// </summary>
        /// <returns>A channel from the end point in the custom configuration file.</returns>
        protected override IDummyService CreateChannel()
        {
            CustomChannelFactory<IDummyService> factory =
                new CustomChannelFactory<IDummyService>(
                    "IDummyServiceBinding", /* or use "*" for the first end point */
                    this.configurationFilePath);
            return factory.CreateChannel();
        }
    }
}
