﻿namespace U2UConsult.WCF.Configuration
{
    using System.ServiceModel;
    using System.ServiceModel.Description;
    using System;
    using System.ServiceModel.Configuration;
    using System.Configuration;
    using System.ServiceModel.Channels;
    using System.Security.Cryptography.X509Certificates;
    using System.Reflection;

    /// <summary>
    /// A custom channel factory which takes in a path to a custom configuration file.
    /// </summary>
    /// <typeparam name="T">Service interface.</typeparam>
    public class CustomChannelFactory<T> : ChannelFactory<T>
    {
        /// <summary>
        /// Path to the configuration file.
        /// </summary>
        private string configurationFileName;

        /// <summary>
        /// Initializes a new instance of the CustomChannelFactory class.
        /// </summary>
        /// <param name="endpointConfigurationName">Name of the endpoint in the configuration file.</param>
        /// <param name="configurationFileName">Path to the configuration file.</param>
        public CustomChannelFactory(string endpointConfigurationName, string configurationFileName)
            : base(typeof(T))
        {
            this.configurationFileName = configurationFileName;
            this.InitializeEndpoint(endpointConfigurationName, null);
        }

        /// <summary>
        /// Applies the configuration found in the custom configuration file.
        /// </summary>
        /// <param name="endpointConfigurationName">Name of the endpoint in the configuration file.</param>
        protected override void ApplyConfiguration(string endpointConfigurationName)
        {
            CustomChannelFactoryHelper.ApplyConfiguration(this.configurationFileName, this.Endpoint, endpointConfigurationName);
        }
    }
}

